==> fap_0.8.8.orig.tar.bz2: fap-0.8.8/src/gui/trackList/trackListM3u.h <==
/*
 *  Copyright (C) 2009-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef TRACKLISTM3U_H
#define TRACKLISTM3U_H

#include "trackListBackend.h"

class trackListM3u : public trackListBackend {

public:
	trackListM3u(const FXString &path) : trackListBackend(path) {};

	/// Load playlist
	FXArray<FXString>* load() {
		const int bufSize=2048;
		FXchar buffer[bufSize+1];
		buffer[bufSize]='\0';

		FXFile file(_path, FXIO::ReadOnly);

		while (const FXival n=file.readBlock(buffer, bufSize)) {
			if (buffer[0]!='#') {
				int i=1;
				while (i<n && Ascii::isPrint(buffer[i])) i++;
				buffer[i]='\0';
				_tracks->append(FXString(buffer));
			}
		}

		file.close();

		return _tracks;
	}

	bool save(const FXArray<FXString>* tracks) {

		FXFile file(_path, FXIO::WriteOnly|FXIO::Create|FXIO::Truncate);

		for (int i=0; i<tracks->no(); i++) {
			writeLine(&file, tracks->at(i));
		}

		file.close();
		return true;
	}
};

#endif

==> fap-0.9.2.tar.bz2: fap-0.9.2/src/gui/trackList/trackListM3u.h <==
/*
 *  Copyright (C) 2009-2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef TRACKLISTM3U_H
#define TRACKLISTM3U_H

#include "trackListBackend.h"

class trackListM3u : public trackListBackend {

public:
	trackListM3u(const FXString &path) : trackListBackend(path) {};

	/// Load playlist
	tracks* load() {
		const int bufSize=2048;
		FXchar buffer[bufSize+1];
		buffer[bufSize]='\0';

		FXFile file(_path, FXIO::ReadOnly);

		while (const FXival n=file.readBlock(buffer, bufSize)) {
			if (buffer[0]!='#') {
				int i=1;
				while (i<n && Ascii::isPrint(buffer[i])) i++;
				buffer[i]='\0';
				_tracks->append(FXString(buffer));
			}
		}

		file.close();

		return _tracks;
	}

	bool save(const tracks* tracks) {

		FXFile file(_path, FXIO::WriteOnly|FXIO::Create|FXIO::Truncate);

		for (int i=0; i<tracks->no(); i++) {
			writeLine(&file, tracks->at(i).location());
		}

		file.close();
		return true;
	}
};

#endif
